ABlog for Sphinx
================

|Build Status|

.. |Build Status| image:: https://dev.azure.com/sunpy/ablog/_apis/build/status/sunpy.ablog?repoName=sunpy%2Fablog&branchName=main
   :target: https://dev.azure.com/sunpy/ablog/_build/latest?definitionId=17&repoName=sunpy%2Fablog&branchName=main

ABlog is a Sphinx extension that converts any documentation or personal website project into a full-fledged blog

`Please check our documentation for information on how to get started. <https://ablog.readthedocs.io/>`__

.. note::

   This is the new home of `Ahmet Bakan's Ablog Sphinx extension <https://github.com/abakan/ablog/>`__.
   The original project is no longer maintained and the `SunPy Project <https://www.sunpy.org>`__ has taken over maintenance.

.. warning::

   **This version is maintained with the aim to keep it working for SunPy Project website and thus new features or bugfixes are highly unlikely unless they directly impact **.
   **We strongly encourage users and interested in parties in submitting patches to ``ablog``.**
